===============
Shared services
===============

This section describes configuring different shared service options
like backends, dashboards and so on.

.. toctree::
   :maxdepth: 2

   glance-guide
   horizon-guide
   keystone-guide
